@@ -214,12 +214,12 @@ class XMLStyleSheet(CLAMMetaData):
 class WaveAudioFormat(CLAMMetaData):
     attributes = {}
     name ="Wave Audio File"
-    mimetype = 'audio/wav'
+    mimetype = 'audio/vnd.wave'
 
 class OggAudioFormat(CLAMMetaData):
     attributes = {}
-    name ="Ogg Audio File"
-    mimetype = 'audio/ogg'
+    name ="Ogg Vorbis Audio File"
+    mimetype = 'audio/vorbis'
 
 class MP3AudioFormat(CLAMMetaData):
     attributes = {}
